<!-- fortunaisk/templates/fortunaisk/base.html -->
{% extends "allianceauth/base-bs5.html" %}
{% load i18n %}
{% load navactive %}
{% load static %}

{% block page_title %}
    {% trans "FortunaIsk" %}
{% endblock page_title %}

{% block head %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static 'css/styles.css' %}">
    <!-- Add Font Awesome CDN -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" integrity="sha512-Fo3rlrQkTyI9rELK9M0VyrCIe4gLLlRdZo8U+qJ1jNfl3zV3eV3UZ6+dJ4uCZfV+1AAhCKZPpbfwS5IsVnP0Mg==" crossorigin="anonymous" referrerpolicy="no-referrer" />
{% endblock head %}

{% block header_nav_brand %}
    <a class="navbar-brand" href="{% url 'fortunaisk:lottery' %}">
        {% trans "FortunaIsk" %}
    </a>
{% endblock header_nav_brand %}

{% block header_nav_collapse_left %}
    <ul class="navbar-nav">
        <li class="nav-item {% navactive request 'fortunaisk:lottery' %}">
            <a class="nav-link" href="{% url 'fortunaisk:lottery' %}">{% trans "Lottery" %}</a>
        </li>
        {% if perms.fortunaisk.can_access_app %}
        <li class="nav-item {% navactive request 'fortunaisk:winner_list' %}">
            <a class="nav-link" href="{% url 'fortunaisk:winner_list' %}">{% trans "Winners" %}</a>
        </li>
        {% endif %}
        <li class="nav-item {% navactive request 'fortunaisk:lottery_history' %}">
            <a class="nav-link" href="{% url 'fortunaisk:lottery_history' %}">{% trans "Lottery History" %}</a>
        </li>
        {% if perms.fortunaisk.can_admin_app %}
        <li class="nav-item {% navactive request 'fortunaisk:admin_dashboard' %}">
            <a class="nav-link" href="{% url 'fortunaisk:admin_dashboard' %}">{% trans "Admin Dashboard" %}</a>
        </li>
        {% endif %}
    </ul>
{% endblock header_nav_collapse_left %}

{% block header_nav_collapse_right %}
    <ul class="navbar-nav ms-auto">
        {% if user.is_authenticated %}
        <li class="nav-item {% navactive request 'fortunaisk:user_dashboard' %}">
            <a class="nav-link" href="{% url 'fortunaisk:user_dashboard' %}">{% trans "My Dashboard" %}</a>
        </li>
        {% else %}
        <li class="nav-item">
            <a class="nav-link" href="{% url 'login' %}">{% trans "Login" %}</a>
        </li>
        {% endif %}
    </ul>
{% endblock header_nav_collapse_right %}

{% block content %}
    {% block details %}{% endblock %}
{% endblock content %}
