/* static/css/styles.css */

body {
    background-color: #f8f9fa;
}

.card {
    margin-bottom: 20px;
    border: 1px solid #ddd;
    border-radius: 5px;
    background-color: #fff;
    box-shadow: 0 4px 6px rgb(0 0 0 / 10%); /* Updated to use modern color-function notation */
}

.table {
    width: 100%;
    margin-bottom: 1rem;
    border-collapse: collapse;
    color: #212529;
}

.table th, .table td {
    padding: 10px;
    text-align: left;
    border-bottom: 1px solid #ddd;
}

.table th {
    background-color: #343a40;
    color: white;
}

.table tr:hover {
    background-color: #f1f1f1;
}

.alert {
    padding: 10px 20px;
    border-radius: 5px;
}

.alert-icon {
    margin-right: 8px;
}
