{% extends "fortunaisk/base.html" %}
{% load i18n static %}

{% block page_title %}
    {% trans "Delete Automatic Lottery" %}
{% endblock page_title %}

{% block details %}
<div class="container mt-5">
    <div class="row justify-content-center">
        <div class="col-md-8">
            <div class="card shadow-lg">
                <div class="card-header bg-danger text-white">
                    <h4 class="mb-0">{% trans "Delete Automatic Lottery" %}</h4>
                </div>
                <div class="card-body">
                    <p class="lead">
                        {% trans "Are you sure you want to delete the automatic lottery" %}
                        <strong>{{ autolottery.name }}</strong>?
                    </p>
                    <form method="post">
                        {% csrf_token %}
                        <div class="d-flex justify-content-end">
                            <a href="{% url 'fortunaisk:admin_dashboard' %}" class="btn btn-secondary me-2">
                                {% trans "Cancel" %}
                            </a>
                            <button type="submit" class="btn btn-danger">
                                <i class="fas fa-trash me-1"></i> {% trans "Delete" %}
                            </button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </div>
</div>
{% endblock details %}
